@@ -8,8 +8,12 @@ has_coc <- function(path = ".") {
     file_exists(path(path, '.github', 'CODE_OF_CONDUCT.md'))
 }
 
-data_home_sidebar_community <- function (pkg){
+has_support <- function(path = ".") {
+  file_exists(path(path, 'SUPPORT.md')) ||
+    file_exists(path(path, '.github', 'SUPPORT.md'))
+}
 
+data_home_sidebar_community <- function(pkg) {
   pkg <- as_pkgdown(pkg)
 
   links <- NULL
@@ -22,10 +26,13 @@ data_home_sidebar_community <- function (pkg){
     links <- c(links, a(tr_("Code of conduct"), "CODE_OF_CONDUCT.html"))
   }
 
+  if (has_support(pkg$src_path)) {
+    links <- c(links, a(tr_("Getting help"), "SUPPORT.html"))
+  }
+
   if (is.null(links)) {
     return("")
   }
 
   sidebar_section(tr_("Community"), links)
-
 }
