@@ -7,7 +7,7 @@
 #' `inst/tutorials` and `vignettes/tutorials`. Alternatively, you can
 #' list in `_pkgdown.yml` as described below.
 #'
-#' @section YAML config:
+#' # YAML config
 #' To override the default discovery process, you can provide a `tutorials`
 #' section. This should be a list where each element specifies:
 #'
@@ -26,9 +26,11 @@
 #'   url: https://jjallaire.shinyapps.io/learnr-tutorial-01-data-basics/
 #' ```
 #' @inheritParams build_articles
+#' @family site components
 #' @export
-build_tutorials <- function(pkg = ".", override = list(), preview = NA) {
-  pkg <- section_init(pkg, depth = 1L, override = override)
+build_tutorials <- function(pkg = ".", override = list(), preview = FALSE) {
+  pkg <- section_init(pkg, "tutorials", override = override)
+
   tutorials <- pkg$tutorials
 
   if (nrow(tutorials) == 0) {
@@ -36,12 +38,13 @@ build_tutorials <- function(pkg = ".", override = list(), preview = NA) {
   }
 
   cli::cli_rule("Building tutorials")
-  create_subdir(pkg, "tutorials")
 
   data <- purrr::transpose(tutorials)
 
   # Build index
-  render_page(pkg, "tutorial-index",
+  render_page(
+    pkg,
+    "tutorial-index",
     data = list(
       pagetitle = tr_("Tutorials"),
       tutorials = purrr::transpose(list(
@@ -93,21 +96,26 @@ find_tutorials <- function(path = ".") {
 
   check_installed("rsconnect", "to find published tutorials")
 
-  rmds <- unname(dir_ls(path, recurse = TRUE, regexp = "\\.[Rrq]md$", type = "file"))
+  rmds <- unname(dir_ls(
+    path,
+    recurse = TRUE,
+    regexp = "\\.[Rrq]md$",
+    type = "file"
+  ))
   info <- purrr::map(rmds, tutorial_info, base_path = path)
   purrr::compact(info)
 }
 
 tutorial_info <- function(path, base_path) {
-  meta <- rmarkdown::yaml_front_matter(path)
-  title <- meta$title
+  yaml <- rmarkdown::yaml_front_matter(path)
+  title <- yaml$title
   if (is.null(title)) {
     return()
   }
 
   # Must have "runtime: shiny". Partial implementation of full algorithm:
   # https://github.com/rstudio/rmarkdown/blob/master/R/shiny.R#L72-L100
-  runtime <- meta$runtime
+  runtime <- yaml$runtime
   if (is.null(runtime) || !grepl("^shiny", runtime)) {
     return()
   }
@@ -125,7 +133,7 @@ tutorial_info <- function(path, base_path) {
 
   list(
     name = as.character(path_ext_remove(path_file(path))),
-    title = meta$title,
+    title = yaml$title,
     url = url
     # source = as.character(path_rel(path, base_path))
   )
