@@ -10,6 +10,7 @@
 #' * [build_tutorials()]
 #' * [build_news()]
 #' * [build_redirects()]
+#' * [build_llm_docs()]
 #'
 #' See the documentation for the each function to learn how to control
 #' that aspect of the site. This page documents options that affect the
@@ -301,6 +302,8 @@
 #'   in the current process affects the build process.
 #' @param install If `TRUE`, will install the package in a temporary library
 #'   so it is available for vignettes.
+#' @param quiet If `FALSE`, generate build messages for build functions that
+#'   take `quiet` arguments.
 #' @export
 #' @examples
 #' \dontrun{
@@ -318,7 +321,8 @@ build_site <- function(
   preview = NA,
   devel = FALSE,
   new_process = !devel,
-  install = !devel
+  install = !devel,
+  quiet = TRUE
 ) {
   pkg <- as_pkgdown(pkg, override = override)
   check_bool(devel)
@@ -352,7 +356,8 @@ build_site <- function(
       lazy = lazy,
       override = override,
       preview = preview,
-      devel = devel
+      devel = devel,
+      quiet = quiet
     )
   } else {
     build_site_local(
@@ -363,7 +368,8 @@ build_site <- function(
       lazy = lazy,
       override = override,
       preview = preview,
-      devel = devel
+      devel = devel,
+      quiet = quiet
     )
   }
 }
@@ -376,7 +382,8 @@ build_site_external <- function(
   lazy = FALSE,
   override = list(),
   preview = NA,
-  devel = TRUE
+  devel = TRUE,
+  quiet = TRUE
 ) {
   pkg <- as_pkgdown(pkg, override = override)
   args <- list(
@@ -390,6 +397,7 @@ build_site_external <- function(
     preview = FALSE,
     new_process = FALSE,
     devel = devel,
+    quiet = quiet,
     cli_colors = cli::num_ansi_colors(),
     hyperlinks = cli::ansi_has_hyperlink_support()
   )
@@ -422,7 +430,8 @@ build_site_local <- function(
   lazy = FALSE,
   override = list(),
   preview = NA,
-  devel = TRUE
+  devel = TRUE,
+  quiet = TRUE
 ) {
   pkg <- section_init(pkg, override = override)
 
@@ -438,7 +447,7 @@ build_site_local <- function(
     init_site(pkg, override)
   }
 
-  build_home(pkg, override = override, preview = FALSE)
+  build_home(pkg, override = override, quiet = quiet, preview = FALSE)
   build_reference(
     pkg,
     lazy = lazy,
@@ -449,10 +458,19 @@ build_site_local <- function(
     preview = FALSE,
     devel = devel
   )
-  build_articles(pkg, lazy = lazy, override = override, preview = FALSE)
+  build_articles(
+    pkg,
+    lazy = lazy,
+    override = override,
+    quiet = quiet,
+    preview = FALSE
+  )
   build_tutorials(pkg, override = override, preview = FALSE)
   build_news(pkg, override = override, preview = FALSE)
   build_sitemap(pkg)
+  if (pkg$bs_version > 3) {
+    build_llm_docs(pkg)
+  }
   build_redirects(pkg, override = override)
   if (pkg$bs_version == 3) {
     build_docsearch_json(pkg)
