@@ -212,8 +212,9 @@ navbar_articles <- function(pkg = ".") {
         vig <- articles[idx, , drop = FALSE]
         vig <- vig[vig$name != pkg$package, , drop = FALSE]
         c(
-          if (!is.null(section$navbar))
-            list(menu_separator(), menu_heading(section$navbar)),
+          if (!is.null(section$navbar)) {
+            list(menu_separator(), menu_heading(section$navbar))
+          },
           menu_links(vig$title, vig$href)
         )
       })
