@@ -216,7 +216,9 @@ check_open_graph <- function(pkg, og, file_path = NULL, call = caller_env()) {
 
 render_template <- function(path, data) {
   template <- read_file(path)
-  if (length(template) == 0) return("")
+  if (length(template) == 0) {
+    return("")
+  }
 
   whisker::whisker.render(template, data)
 }
@@ -271,7 +273,9 @@ write_if_different <- function(
 }
 
 same_contents <- function(path, contents) {
-  if (!file_exists(path)) return(FALSE)
+  if (!file_exists(path)) {
+    return(FALSE)
+  }
 
   new_hash <- rlang::hash(contents)
 
@@ -290,13 +294,17 @@ file_digest <- function(path) {
 }
 
 made_by_pkgdown <- function(path) {
-  if (!file_exists(path)) return(TRUE)
+  if (!file_exists(path)) {
+    return(TRUE)
+  }
 
   first <- paste(read_lines(path, n = 2), collapse = "\n")
   check_made_by(first)
 }
 
 check_made_by <- function(first) {
-  if (length(first) == 0L) return(FALSE)
+  if (length(first) == 0L) {
+    return(FALSE)
+  }
   grepl("<!-- Generated by pkgdown", first, fixed = TRUE)
 }
