@@ -4,26 +4,22 @@
 #' @param a a letter
 #' @param b a a number
 #' @param c a logical
-a <- function(a, b, c) {
-}
+a <- function(a, b, c) {}
 
 #' B
 #' @export
 #' @concept graphics
-b <- function() {
-}
+b <- function() {}
 
 #' C
 #' @export
-c <- function() {
-}
+c <- function() {}
 
 #' D
 #' @usage
 #' \special{?topic}
 #' @export
-`?` <- function() {
-}
+`?` <- function() {}
 
 #' E
 #' @name e
