@@ -1,6 +1,7 @@
 test_that("data_news works as expected for h1 & h2", {
   skip_if_no_pandoc()
 
+  # fmt: skip
   lines_h1 <- c(
     "# testpackage 1.0.0.9000", "",
     "* bullet (#222 @someone)", "",
@@ -21,12 +22,16 @@ test_that("data_news works as expected for h1 & h2", {
 
 test_that("news is syntax highlighted once", {
   pkg <- local_pkgdown_site()
-  pkg <- pkg_add_file(pkg, "NEWS.md", c(
-    "# testpackage 1.0.0.9000",
-    "```r", 
-    "x <- 1", 
-    "```"
-  ))
+  pkg <- pkg_add_file(
+    pkg,
+    "NEWS.md",
+    c(
+      "# testpackage 1.0.0.9000",
+      "```r",
+      "x <- 1",
+      "```"
+    )
+  )
   suppressMessages(build_news(pkg, preview = FALSE))
   html <- xml2::read_html(path(pkg$dst_path, "news", "index.html"))
   expect_equal(xpath_text(html, "//code"), "x <- 1")
@@ -36,6 +41,7 @@ test_that("multi-page news are rendered", {
   skip_if_no_pandoc()
 
   pkg <- local_pkgdown_site(meta = list(news = list(one_page = FALSE)))
+  # fmt: skip
   pkg <- pkg_add_file(pkg, "NEWS.md", c(
     "# testpackage 2.0", "",
     "* bullet (#222 @someone)", "",
@@ -66,22 +72,28 @@ test_that("multi-page news are rendered", {
   # test single page structure
   lines <- xml2::read_html(path(pkg$dst_path, "news", "news-1.0.html"))
   expect_equal(xpath_text(lines, ".//h1"), "Version 1.0")
-  expect_equal(xpath_text(lines, ".//main//h2"), c("testpackage 1.0.0", "testpackage 1.0.1"))
+  expect_equal(
+    xpath_text(lines, ".//main//h2"),
+    c("testpackage 1.0.0", "testpackage 1.0.1")
+  )
 })
 
 test_that("github links are added to news items", {
   skip_if_no_pandoc()
 
-  pkg <- local_pkgdown_site(meta = list(
-    repo = list(
-      url = list(
-        home = "https://github.com/r-lib/pkgdown",
-        user = "https://github.com/",
-        issue = "https://github.com/r-lib/pkgdown/issues/"
+  pkg <- local_pkgdown_site(
+    meta = list(
+      repo = list(
+        url = list(
+          home = "https://github.com/r-lib/pkgdown",
+          user = "https://github.com/",
+          issue = "https://github.com/r-lib/pkgdown/issues/"
+        )
       )
     )
-  ))
+  )
 
+  # fmt: skip
   pkg <- pkg_add_file(pkg, "NEWS.md", c(
     "# testpackage 0.1.0", "",
     "## Major changes", "",
@@ -117,8 +129,7 @@ test_that("correct timeline for first ggplot2 releases", {
   timeline <- pkg_timeline("ggplot2")[1:3, ]
   expected <- data.frame(
     version = c("0.5", "0.5.1", "0.5.2"),
-    date = as.Date(c("2007-06-01", "2007-06-09", "2007-06-18")),
-    stringsAsFactors = FALSE
+    date = as.Date(c("2007-06-01", "2007-06-09", "2007-06-18"))
   )
 
   expect_equal(timeline, expected)
@@ -128,14 +139,17 @@ test_that("correct timeline for first ggplot2 releases", {
 
 test_that("can recognise common forms of title", {
   # Variants in beginning
-  version <- news_version(c(
-    "foo 1.3.0",
-    "foo v1.3.0",
-    "foo 1.3.0",
-    "VERSION 1.3.0",
-    "changes in 1.3.0",
-    "changes in foo version 1.3.0"
-  ), "foo")
+  version <- news_version(
+    c(
+      "foo 1.3.0",
+      "foo v1.3.0",
+      "foo 1.3.0",
+      "VERSION 1.3.0",
+      "changes in 1.3.0",
+      "changes in foo version 1.3.0"
+    ),
+    "foo"
+  )
   expect_equal(version, rep("1.3.0", length(version)))
 
   # Variants in version spec
@@ -159,22 +173,26 @@ test_that("correctly collapses version to page for common cases", {
 # Tweaks ------------------------------------------------------------------
 
 test_that("sections tweaked down a level", {
-  html <- xml2::read_xml("<body>
+  html <- xml2::read_xml(
+    "<body>
     <div class='section level1'><h1></h1></div>
     <div class='section level2'><h2></h2></div>
     <div class='section level3'><h3></h3></div>
     <div class='section level4'><h4></h4></div>
     <div class='section level5'><h5></h5></div>
-  </body>")
+  </body>"
+  )
   tweak_section_levels(html)
   expect_equal(xml2::xml_name(xpath_xml(html, "//div/*")), paste0("h", 2:6))
   expect_equal(xpath_attr(html, "//div", "class"), paste0("section level", 2:6))
 })
 
 test_that("anchors de-duplicated with version", {
-  html <- xml2::read_xml("<body>
+  html <- xml2::read_xml(
+    "<body>
     <div class='section' id='x-1'>Heading</div>
-  </body>")
+  </body>"
+  )
   tweak_news_anchor(html, "1.0")
 
   expect_equal(xpath_attr(html, ".//div", "id"), "x-1-0")
@@ -195,6 +213,7 @@ test_that("news headings get class and release date", {
 # Header checks ----------------------------------------------------------
 test_that("clear error for bad hierarchy - bad nesting", {
   pkg <- local_pkgdown_site()
+  # fmt: skip
   pkg <- pkg_add_file(pkg, "NEWS.md", c(
     "### testpackage 1.0.0.9000", "",
     "* bullet (#222 @someone)", "",
@@ -209,6 +228,7 @@ test_that("clear error for bad hierarchy - bad nesting", {
 
 test_that("clear error for bad hierarchy - h3", {
   pkg <- local_pkgdown_site()
+  # fmt: skip
   pkg <- pkg_add_file(pkg, "NEWS.md", c(
     "### testpackage 1.0.0.9000", "",
     "* bullet (#222 @someone)", "",
@@ -223,6 +243,7 @@ test_that("clear error for bad hierarchy - h3", {
 
 test_that("news can contain footnotes", {
   pkg <- local_pkgdown_site()
+  # fmt: skip
   pkg <- pkg_add_file(pkg, "NEWS.md", c(
     "## testpackage 1.0.0.9000",
     "",
@@ -239,10 +260,18 @@ test_that("data_news warns if no headings found", {
   skip_if_no_pandoc()
 
   pkg <- local_pkgdown_site()
-  pkg <- pkg_add_file(pkg, "NEWS.md", c(
-    "# mypackage", "",
-    "## mypackage foo", "",
-    "## mypackage bar", ""
-  ))
+  # fmt: skip
+  pkg <- pkg_add_file(
+    pkg,
+    "NEWS.md",
+    c(
+      "# mypackage",
+      "",
+      "## mypackage foo",
+      "",
+      "## mypackage bar",
+      ""
+    )
+  )
   expect_snapshot(. <- data_news(pkg))
 })
