@@ -13,6 +13,10 @@ test_that("can override defaults in _pkgdown.yml", {
   expect_setequal(img, c("figure-1.jpg", "figure-2.jpg"))
 
   suppressMessages(build_articles(pkg))
-  img <- path_file(dir_ls(path(pkg$dst_path, "articles"), glob = "*.jpg", recurse = TRUE))
+  img <- path_file(dir_ls(
+    path(pkg$dst_path, "articles"),
+    glob = "*.jpg",
+    recurse = TRUE
+  ))
   expect_equal(img, "unnamed-chunk-1-1.jpg")
 })
